==> owncloud-9.1.8.tar.bz2: owncloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Powiadomienia o aktualizacji",
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Dowiedz się jak zaktualizować.",
    "Updated channel" : "Zaktualizowano kanał",
    "ownCloud core" : "Rdzeń ownCloud",
    "Update for %1$s to version %2$s is available." : "Jest dostępna aktualizacja dla %1$s do wersji %2$s",
    "Updater" : "Aktualizator",
    "A new version is available: %s" : "Dostępna jest nowa wersja: %s",
    "Open updater" : "Otwórz aktualizator",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "Checked on %s" : "Sprawdzone na %s",
    "Update channel:" : "Kanał aktualizacji:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Możesz zawsze zaktualizować swoją wersję do nowego / ekperymentalnego kanału. Jednakże nie możesz powrócić do poprzedniej stabilniejszej wersji.  ",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach: ",
    "Only notification for app updates are available, because the selected update channel for ownCloud itself does not allow notifications." : "Tylko powiadomienia o aktualizacjach aplikacji są dostępne, gdyż wybrany kanał aktualizacji ownCloud nie zezwala na powiadomienia. "
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.16.0.tar.bz2: owncloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Update notifications" : "Powiadomienia o aktualizacji",
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Dowiedz się jak zaktualizować.",
    "Updated channel" : "Zaktualizowano kanał",
    "ownCloud core" : "Rdzeń ownCloud",
    "Update for %1$s to version %2$s is available." : "Jest dostępna aktualizacja dla %1$s do wersji %2$s",
    "Updater" : "Aktualizator",
    "A new version is available: %s" : "Dostępna jest nowa wersja: %s",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "Checked on %s" : "Sprawdzone na %s",
    "Update channel:" : "Kanał aktualizacji:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Możesz zawsze zaktualizować swoją wersję do nowego / ekperymentalnego kanału. Jednakże nie możesz powrócić do poprzedniej stabilniejszej wersji.  ",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach: ",
    "Only notification for app updates are available, because the selected update channel for ownCloud itself does not allow notifications." : "Tylko powiadomienia o aktualizacjach aplikacji są dostępne, gdyż wybrany kanał aktualizacji ownCloud nie zezwala na powiadomienia. "
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
